@@ -1,4 +1,6 @@
 <?php
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/timeout.php,v 1.5.2.1 2007/12/21 12:11:55 wurley Exp $
+
 /**
  * Time out page to be displayed on the right frame
  *
@@ -13,8 +15,10 @@
 
 require './common.php';
 
-if (! isset($ldapserver))
+if (! isset($ldapserver)) {
 	header("Location: index.php");
+	die();
+}
 
 include './header.php';
 
@@ -30,7 +34,7 @@ $session_timeout = $ldapserver->session_timeout ? $ldapserver->session_timeout :
 	<br />
 	<br />
 	<?php echo _('To log back in please click on the following link:'); ?><br />
-	<a href="login_form.php?server_id=<?php echo $ldapserver->server_id; ?>"><?php echo _('Login...'); ?></a>
+	<a href="cmd.php?cmd=login_form&server_id=<?php echo $ldapserver->server_id; ?>"><?php echo _('Login...'); ?></a>
 </center>
 
 </body>
